pub enum Error {
Io(Error),
Exists,
UniqueId,
InvalidId(String),
InvalidBlockSize(u32),
}Expand description
The error type for the directory backend.
Variants
Io(Error)
An I/O error occured.
Exists
You are creating a new backend which already exists.
UniqueId
Could not generate a unique id.
InvalidId(String)
The id is invalid, is not a hex string.
InvalidBlockSize(u32)
The block size passed to CreateOptions is invalid.